@@ -1,6 +1,5 @@
 from importlib import import_module
 
-import django
 from django.db import transaction
 
 from rest_framework.response import Response
@@ -65,11 +64,7 @@ class BatchView(APIView):
                 if current_request.name in responses:
                     continue
 
-                # Due django.http.response.HttpResponseBase changes
-                if django.VERSION < (3, 2):
-                    header_items = response._headers.values()
-                else:
-                    header_items = response.headers.items()
+                header_items = response.items()
 
                 result = BatchResponse(
                     current_request.name,
